# unitorch.models.bloom

## BloomProcessor

::: unitorch.models.bloom.BloomProcessor

## BloomForClassification

::: unitorch.models.bloom.BloomForClassification

## BloomForPretrain

::: unitorch.models.bloom.BloomForPretrain

## BloomForGeneration

::: unitorch.models.bloom.BloomForGeneration
